>From 095c8ff025d168c2aa6847f6dd0a7c78191c708d Mon Sep 17 00:00:00 2001
From: Stefan Tauner <stefan.tauner@student.tuwien.ac.at>
Date: Thu, 21 Jul 2011 11:25:01 +0200
Subject: [PATCH] ichspi: improve prettyprint_opcodes

add headers for the columns and some decoding into human readable format.
further improvements could be made with a generic opcode -> name string decoder.

Signed-off-by: Stefan Tauner <stefan.tauner@student.tuwien.ac.at>
---
 ichspi.c |   34 +++++++++++++++++++++++-----------
 1 files changed, 23 insertions(+), 11 deletions(-)

diff --git a/ichspi.c b/ichspi.c
index 283dcf7..7928cae 100644
--- a/ichspi.c
+++ b/ichspi.c
@@ -295,22 +295,34 @@ static OPCODES O_EXISTING = {};
 /* pretty printing functions */
 static void prettyprint_opcodes(OPCODES *ops)
 {
-	if(ops == NULL)
-		return;
-
-	msg_pdbg("preop0=0x%02x, preop1=0x%02x\n", ops->preop[0],
-		 ops->preop[1]);
-
 	OPCODE oc;
+	const char *t;
+	const char *a;
 	uint8_t i;
+	static const char *const spi_type[4] = {
+		"read  w/o addr",
+		"write w/o addr",
+		"read  w/  addr",
+		"write w/  addr"
+	};
+	static const char *const atomic_type[3] = {
+		"none",
+		" 0  ",
+		" 1  "
+	};
+
+	if (ops == NULL)
+		return;
+
+	msg_pdbg("        OP        Type      Pre-OP\n");
 	for (i = 0; i < 8; i++) {
 		oc = ops->opcode[i];
-		msg_pdbg("op[%d]=0x%02x, %d, %d\n",
-			 i,
-			 oc.opcode,
-			 oc.spi_type,
-			 oc.atomic);
+		t = (oc.spi_type > 3) ? "invalid" : spi_type[oc.spi_type];
+		a = (oc.atomic > 2) ? "invalid" : atomic_type[oc.atomic];
+		msg_pdbg("op[%d]: 0x%02x, %s, %s\n", i, oc.opcode, t, a);
 	}
+	msg_pdbg("Pre-OP 0: 0x%02x, Pre-OP 1: 0x%02x\n", ops->preop[0],
+		 ops->preop[1]);
 }
 
 static void prettyprint_ich9_reg_hsfs(uint16_t reg_val)
-- 
1.7.1

